/*
** file.h -- file handling routines for ShowTime
**
** Michael J. Gourlay 1993, 1994
*/

#ifndef _FILE_H_INCLUDED_
#define _FILE_H_INCLUDED_

#include <stdio.h>
#include "showtime.h"

/* ====================================================================== */

/* get_byte : get from fio a byte
*/
#define GET_BYTE(fio, byte) \
{\
  int rv;\
  (byte)=(unsigned char)(rv=getc(fio));\
  if(rv==EOF) {\
    logmesg("get_byte: EOF/read error\n");\
    return(EOF);\
  }\
}

/* ====================================================================== */

/* Define macros to get integers and reject negative numbers */
/* NONEGA reads an ASCII integer, and barfs if the value is negative */
#define NONEGA(var, msg) if(((var)=sc_getint(fio))<0) {\
  logmesg("read negative value for %s\n", msg); return(EOF); }

/* NONEGB reads an Binary integer, and barfs if the value is negative */
#define NONEGB(var, msg) if(((var)=get_le_word(fio))<0) {\
  logmesg("read negative value for %s\n", msg); return(EOF); }

/* ====================================================================== */

/* get_le_word : get from fio a 2-byte little-endian unsigned integer */
extern long get_le_word(FILE * fio);

/* get_block : get from fio an block of n bytes, and store it in buf
** return EOF if there is a read error, or 0 otherwise
*/
extern short get_block(FILE * fio, unsigned char *buf, long n);

/* open_file : open a file and return its file pointer or descriptor */
extern FILE * open_file(char *filename);

#endif /* _FILE_H_INCLUDED_ */
